@@ -13,7 +13,9 @@ def requires_alastria_auth(view):
         if "HTTP_ALASTRIA_TOKEN" not in request.request.META.keys():  # Alastria-Token
             raise PermissionDenied
         else:
-            AlastriaAuthService.validate_permission(request.request.META["HTTP_ALASTRIA_TOKEN"])
+            AlastriaAuthService.validate_permission(
+                request.request.META["HTTP_ALASTRIA_TOKEN"]
+            )
         return view(request, *args, **kwargs)
 
     return _view
