@@ -5,9 +5,7 @@ from django.utils.timezone import now
 
 class RequestSession(models.Model):
     request_date = models.DateTimeField()
-    expiration_date = models.DateTimeField(
-        default=now() + timedelta(minutes=5), verbose_name="Expirate date"
-    )
+    expiration_date = models.DateTimeField(verbose_name="Expirate date")
     requested_by = models.CharField(max_length=255)
     qr_code = models.ImageField()
     confirm_url = models.CharField(max_length=255)
@@ -16,9 +14,8 @@ class RequestSession(models.Model):
 
 class ApiSession(models.Model):
 
-    token = models.CharField(max_length=255)
-    expiration_date = models.DateTimeField(
-        default=now() + timedelta(days=3), verbose_name="Expirate date"
-    )
+    token = models.CharField(max_length=1255)
+    expiration_date = models.DateTimeField(verbose_name="Expirate date")
     is_active = models.BooleanField(default=True)
     request_session_id = models.IntegerField()
+    extra_info = models.JSONField(blank=True, null=True)
